from distutils.core import setup

setup(
    name = 'wvely',
    version = '1.3.0',
    py_modules = ['wvely'],  #将模块的元数据与setup函数的参数关联
    author = 'wvely',
    author_email= '781224336@qq.com',
    url = 'http://www.headfirstlabs.com',
    description= 'A simple printer of lists'
)